@@ -5,10 +5,9 @@
 #' The methods and the package are explained in detail in Adämmer (2019) <doi:10.32614/RJ-2019-052>.
 #' Please cite the paper when using the package.
 #'
-#' @docType package
 #' @author Philipp Adämmer
 #' @importFrom Rcpp evalCpp
 #' @useDynLib lpirfs, .registration = TRUE
 #' @exportPattern "^[[:alpha:]]+"
 #' @name lpirfs-package
-NULL
+"_PACKAGE"
